# Changelog for valarpy

Adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html)
and [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).


## [2.0.0] - 2020-08-11

### Changed:
- Build infrastructure and code organization.
